package es.uva.tfg.geolocalizationgame.controllers;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.http.MediaType;
import org.springframework.http.ResponseEntity;
import org.springframework.security.core.Authentication;
import org.springframework.security.core.context.SecurityContextHolder;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;

import com.fasterxml.jackson.annotation.JsonView;

import es.uva.tfg.geolocalizationgame.resources.Usuario;
import es.uva.tfg.geolocalizationgame.resources.DatosUser;
import es.uva.tfg.geolocalizationgame.services.UserService;

/**
 * Clase controladora para la autenticacion en el sistema.
 * 
 * @author Cristina Gomez Escribano
 * @version 1.0
 * @since 2/9/2018
 *
 */
@Controller
@RequestMapping(path = "/authentication")
public class AuthenticationController {
	
	@Autowired
	private UserService userService;
	/**
	 * Recibe la peticion get para obtener el usuario autenticado en el sistema
	 * 
	 * @return ResponseEntity<Usuario> con el status http correspondiente y el
	 *         usuario autenticado en el sistema
	 */
	@JsonView(DatosUser.Basic.class)
	@RequestMapping(method = RequestMethod.GET, produces = MediaType.APPLICATION_JSON_VALUE)
	public ResponseEntity<Usuario> getUsuarioAuth() {
		Authentication auth = SecurityContextHolder.getContext().getAuthentication();
		Usuario userAuth=userService.obtenerUsuarioByLogin(auth.getName());
		return new ResponseEntity<Usuario>(userAuth, HttpStatus.OK);
	}
}
