package es.uva.tfg.geolocalizationgame.controllers;

import org.springframework.web.bind.annotation.ControllerAdvice;
import org.springframework.web.bind.annotation.ExceptionHandler;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.ResponseStatus;
import org.springframework.web.servlet.mvc.method.annotation.ResponseEntityExceptionHandler;

import es.uva.tfg.geolocalizationgame.exceptions.AmistadExistException;
import es.uva.tfg.geolocalizationgame.exceptions.AmistadNotFoundException;
import es.uva.tfg.geolocalizationgame.exceptions.ComentarioNotFoundException;
import es.uva.tfg.geolocalizationgame.exceptions.EstadoSolicitudNotFoundException;
import es.uva.tfg.geolocalizationgame.exceptions.JuegoNotVisibleForUserException;
import es.uva.tfg.geolocalizationgame.exceptions.JuegoNotFoundException;
import es.uva.tfg.geolocalizationgame.exceptions.LogroNotFoundException;
import es.uva.tfg.geolocalizationgame.exceptions.MalformedRequestException;
import es.uva.tfg.geolocalizationgame.exceptions.ModalidadDeJuegoNotFoundException;
import es.uva.tfg.geolocalizationgame.exceptions.NivelDificultadNotFoundException;
import es.uva.tfg.geolocalizationgame.exceptions.PuntoGeograficoExistException;
import es.uva.tfg.geolocalizationgame.exceptions.PuntoGeograficoIsLastException;
import es.uva.tfg.geolocalizationgame.exceptions.PuntoGeograficoNotFoundException;
import es.uva.tfg.geolocalizationgame.exceptions.PuntoGeograficoNotInGameException;
import es.uva.tfg.geolocalizationgame.exceptions.SolicitudAmistadExistException;
import es.uva.tfg.geolocalizationgame.exceptions.SolicitudAmistadNotFoundException;
import es.uva.tfg.geolocalizationgame.exceptions.TipoLogroNotFoundException;
import es.uva.tfg.geolocalizationgame.exceptions.TipoPuntoNotFoundException;
import es.uva.tfg.geolocalizationgame.exceptions.TipoVisibilidadNotFoundException;
import es.uva.tfg.geolocalizationgame.exceptions.UserExistException;
import es.uva.tfg.geolocalizationgame.exceptions.UserNotCreatorOfComentarioException;
import es.uva.tfg.geolocalizationgame.exceptions.UserNotCreatorOfJuegoException;
import es.uva.tfg.geolocalizationgame.exceptions.UserNotFoundException;
import es.uva.tfg.geolocalizationgame.exceptions.UserPassException;
import es.uva.tfg.geolocalizationgame.resources.ErrorMessage;

import org.springframework.http.HttpStatus;

/**
 * Controlador de excepciones.
 * 
 * @author Cristina Gomez Escribano
 * @version 3.0
 * @since 12/12/2018
 *
 */
@ControllerAdvice
public class ExceptionHandlerController extends ResponseEntityExceptionHandler {

	@ResponseStatus(HttpStatus.NOT_FOUND)
	@ExceptionHandler({UserNotFoundException.class, SolicitudAmistadNotFoundException.class, EstadoSolicitudNotFoundException.class, AmistadNotFoundException.class, TipoLogroNotFoundException.class, LogroNotFoundException.class, TipoVisibilidadNotFoundException.class, JuegoNotFoundException.class, UserNotCreatorOfJuegoException.class, ComentarioNotFoundException.class, UserNotCreatorOfComentarioException.class, TipoPuntoNotFoundException.class, PuntoGeograficoNotFoundException.class, PuntoGeograficoNotInGameException.class, ModalidadDeJuegoNotFoundException.class, NivelDificultadNotFoundException.class})
	@ResponseBody
	public ErrorMessage notFoundException(Exception exception) {
		return new ErrorMessage(exception);
	}
	
	@ResponseStatus(HttpStatus.BAD_REQUEST)
	@ExceptionHandler({MalformedRequestException.class, UserPassException.class})
	@ResponseBody
	public ErrorMessage malformedRequestException(Exception exception) {
		return new ErrorMessage(exception);
	}
	
	@ResponseStatus(HttpStatus.FOUND)
	@ExceptionHandler({UserExistException.class, SolicitudAmistadExistException.class, AmistadExistException.class, PuntoGeograficoExistException.class})
	@ResponseBody
	public ErrorMessage entityExistException(Exception exception) {
		return new ErrorMessage(exception);
	}
	
	@ResponseStatus(HttpStatus.UNAUTHORIZED)
	@ExceptionHandler({JuegoNotVisibleForUserException.class})
	@ResponseBody
	public ErrorMessage unAuthorizedException(Exception exception) {
		return new ErrorMessage(exception);
	}
	
	@ResponseStatus(HttpStatus.NOT_ACCEPTABLE)
	@ExceptionHandler({PuntoGeograficoIsLastException.class})
	@ResponseBody
	public ErrorMessage notAcceptableException(Exception exception) {
		return new ErrorMessage(exception);
	}

}
