package es.uva.tfg.geolocalizationgame.persistence;

import java.io.Serializable;
import java.util.List;

import javax.transaction.Transactional;

import org.springframework.data.jpa.repository.JpaRepository;
import org.springframework.data.jpa.repository.Modifying;
import org.springframework.data.jpa.repository.Query;
import org.springframework.data.repository.query.Param;

import es.uva.tfg.geolocalizationgame.resources.Juego;
import es.uva.tfg.geolocalizationgame.resources.Usuario;

/**
 *  Implementa la clase de persistencia para la entidad Juego.
 *  
 * @author Cristina Gomez Escribano
 * @since 12/11/2018
 * @version 2.0
 *
 */
public interface JuegoRepository extends JpaRepository<Juego, Serializable> {

	/**
	 * Obtiene los juegos creados por el usuario pasado como parametro
	 * 
	 * @param usuario
	 * @return
	 */
	@Query(value = "SELECT juego from Juego juego WHERE juego.creador=:usuario")
	List<Juego> obtenerJuegosUser(@Param(value="usuario") Usuario usuario);

	/**
	 * Obtiene los juegos con visibilidad publica que contengan un texto pasado como parametro
	 * 
	 * @param texto
	 * @return
	 */
	@Query(value = "SELECT juego from Juego juego WHERE juego.visibilidad.tipoVisibilidad='publico' and (UPPER(juego.nombre) LIKE CONCAT('%',:texto,'%'))")
	List<Juego> obtenerJuegosPublicosByTexto(@Param(value="texto") String texto);

	/**
	 * Elimina todos los aciertos de los puntos del juego pasado como parametro
	 * 
	 * @param idJuego
	 */
	@Modifying
	@Transactional
	@Query(value = "DELETE a FROM acierto a inner join punto_geografico p on p.ID_PUNTO=a.ID_PUNTO where p.ID_JUEGO=:idJuego", nativeQuery = true)
	void deleteAciertos(@Param(value="idJuego") Integer idJuego);
	
	/**
	 *  Elimina todos los fallos de los puntos del juego pasado como parametro
	 *  
	 * @param idJuego
	 */
	@Modifying
	@Transactional
	@Query(value = "DELETE f FROM fallo f inner join punto_geografico p on p.ID_PUNTO=f.ID_PUNTO where p.ID_JUEGO=:idJuego", nativeQuery = true)
	void deleteFallos(@Param(value="idJuego") Integer idJuego);
	
	/**
	 *  Elimina todos los puntos conseguidos de los puntos del juego pasado como parametro
	 *  
	 * @param idJuego
	 */
	@Modifying
	@Transactional
	@Query(value = "DELETE pc FROM punto_conseguido pc inner join punto_geografico p on p.ID_PUNTO=pc.ID_PUNTO where p.ID_JUEGO=:idJuego", nativeQuery = true)
	void deleteConseguidos(@Param(value="idJuego") Integer idJuego);

}
