package es.uva.tfg.geolocalizationgame.persistence;

import java.io.Serializable;
import java.util.List;

import org.springframework.data.jpa.repository.JpaRepository;
import org.springframework.data.jpa.repository.Query;
import org.springframework.data.repository.query.Param;


import es.uva.tfg.geolocalizationgame.resources.Usuario;

/**
 * Repositorio para la entidad usuario.
 * Incluye las funciones con las consultas a la base de datos
 * 
 * @author Cristina Gómez Escribano
 * @version 1.0
 * @since 02/05/2017
 *
 */
public interface UsuarioRepository extends JpaRepository<Usuario, Serializable> {

	/**
	 * Obtiene los usuarios cuyo login o nombre contiene el texto introducido como parametro
	 * 
	 * @param texto
	 * @return lista de usuarios
	 */
	@Query("select usuario from Usuario usuario where (UPPER(usuario.login) LIKE CONCAT('%',:texto,'%') OR UPPER(usuario.nombre) LIKE CONCAT('%',:texto,'%'))")
	List<Usuario> obtenerUsuariosByText(@Param(value = "texto") String texto);
}
