package es.uva.tfg.geolocalizationgame.resources;

import java.io.Serializable;
import java.util.Date;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.Table;
import javax.persistence.Temporal;
import javax.persistence.TemporalType;
import javax.validation.constraints.NotNull;
import javax.validation.constraints.Size;

import com.fasterxml.jackson.annotation.JsonView;

/**
 * Definicion de la entidad Comentario.
 * 
 * @author Cristina Gomez Escribano
 * @version 5.0
 * @since 12/08/2018
 *
 */
@Entity
@Table(name = "comentario")
public class Comentario implements Serializable {

	/**
	 * 
	 */
	private static final long serialVersionUID = 1L;

	@Id
	@GeneratedValue(strategy = GenerationType.AUTO)
	@JsonView(DatosUser.GameView.class)
	@Column(name="ID_COMENTARIO", unique = true)
	private Integer idComentario;

	@JsonView(DatosUser.GameView.class)
	@Column(name="DESCRIPCION")
	@Size(min = 3, max = 150)
	@NotNull
	private String descripcion;
	
	@JsonView(DatosUser.GameView.class)
	@NotNull
	@Column(name="FECHA_EMISION")
	@Temporal(TemporalType.TIMESTAMP)
	private Date fechaCreacion;
	
	@JsonView(DatosUser.GameView.class)
	@NotNull
	@Column(name="FECHA_MODIFICACION")
	@Temporal(TemporalType.TIMESTAMP)
	private Date fechaModificacion;
	
	@ManyToOne
	@JoinColumn(name="ID_JUEGO")
	@NotNull
	private Juego juego;
	
	@JsonView(DatosUser.GameView.class)
	@ManyToOne
	@JoinColumn(name="LOGIN_CREADOR")
	@NotNull
	private Usuario creador;

	public Comentario() {
		super();
	}

	public Comentario(Integer idComentario, String descripcion, Date fechaCreacion, Date fechaModificacion, Juego juego,
			Usuario creador) {
		super();
		this.idComentario = idComentario;
		this.descripcion = descripcion;
		this.fechaCreacion = fechaCreacion;
		this.fechaModificacion = fechaModificacion;
		this.juego = juego;
		this.creador = creador;
	}

	public Integer getIdComentario() {
		return idComentario;
	}

	public void setIdComentario(Integer idComentario) {
		this.idComentario = idComentario;
	}

	public String getDescripcion() {
		return descripcion;
	}

	public void setDescripcion(String descripcion) {
		this.descripcion = descripcion;
	}

	public Date getFechaCreacion() {
		return fechaCreacion;
	}

	public void setFechaCreacion(Date fechaCreacion) {
		this.fechaCreacion = fechaCreacion;
	}

	public Date getFechaModificacion() {
		return fechaModificacion;
	}

	public void setFechaModificacion(Date fechaModificacion) {
		this.fechaModificacion = fechaModificacion;
	}

	public Juego getJuego() {
		return juego;
	}

	public void setJuego(Juego juego) {
		this.juego = juego;
	}

	public Usuario getCreador() {
		return creador;
	}

	public void setCreador(Usuario creador) {
		this.creador = creador;
	}

	@Override
	public String toString() {
		return "Comentario [idComentario=" + idComentario + ", descripcion=" + descripcion + ", fechaCreacion="
				+ fechaCreacion + ", fechaModificacion=" + fechaModificacion + ", juego=" + juego + ", creador="
				+ creador + "]";
	}
}
