package es.uva.tfg.geolocalizationgame.resources;

import java.io.Serializable;
import java.util.Date;

import javax.persistence.Column;
import javax.persistence.EmbeddedId;
import javax.persistence.Entity;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.Table;
import javax.persistence.Temporal;
import javax.persistence.TemporalType;
import javax.validation.constraints.NotNull;

import com.fasterxml.jackson.annotation.JsonView;

/**
 * Definicion de la entidad Logro.
 * 
 * @author Cristina Gomez Escribano
 * @version 5.0
 * @since 12/09/2018
 *
 */
@Entity
@Table(name="logro")
public class Logro implements Serializable{

	/**
	 * 
	 */
	private static final long serialVersionUID = 1L;

	@EmbeddedId
	@JsonView(DatosUser.PrivateProfile.class)
	private LogroPK id;
	
	@NotNull
	@Column(name="FECHA_CONSEGUIDO")
	@Temporal(TemporalType.TIMESTAMP)
	@JsonView(DatosUser.PrivateProfile.class)
	private Date fechaConseguido;
	
	@NotNull
	@Column(name="FECHA_MODIFICACION")
	@Temporal(TemporalType.TIMESTAMP)
	@JsonView(DatosUser.PrivateProfile.class)
	private Date fechaModificacion;
	
	@NotNull
	@JoinColumn(name="ID_TIPO_VISIBILIDAD", referencedColumnName="ID_TIPO_VISIBILIDAD", nullable=false)
	@JsonView(DatosUser.PrivateProfile.class)
	@ManyToOne(optional=false)
	private TipoVisibilidad tipoVisibilidad;

	public Logro() {
		super();
	}

	public Logro(LogroPK id, Date fechaConseguido, Date fechaModificacion, TipoVisibilidad tipoVisibilidad) {
		super();
		this.id = id;
		this.fechaConseguido = fechaConseguido;
		this.fechaModificacion = fechaModificacion;
		this.tipoVisibilidad = tipoVisibilidad;
	}

	public LogroPK getId() {
		return id;
	}

	public void setId(LogroPK id) {
		this.id = id;
	}

	public Date getFechaConseguido() {
		return fechaConseguido;
	}

	public void setFechaConseguido(Date fechaConseguido) {
		this.fechaConseguido = fechaConseguido;
	}

	public Date getFechaModificacion() {
		return fechaModificacion;
	}

	public void setFechaModificacion(Date fechaModificacion) {
		this.fechaModificacion = fechaModificacion;
	}

	public TipoVisibilidad getTipoVisibilidad() {
		return tipoVisibilidad;
	}

	public void setTipoVisibilidad(TipoVisibilidad tipoVisibilidad) {
		this.tipoVisibilidad = tipoVisibilidad;
	}

	@Override
	public int hashCode() {
		final int prime = 31;
		int result = 1;
		result = prime * result + ((fechaConseguido == null) ? 0 : fechaConseguido.hashCode());
		result = prime * result + ((fechaModificacion == null) ? 0 : fechaModificacion.hashCode());
		result = prime * result + ((id == null) ? 0 : id.hashCode());
		result = prime * result + ((tipoVisibilidad == null) ? 0 : tipoVisibilidad.hashCode());
		return result;
	}

	@Override
	public boolean equals(Object obj) {
		if (this == obj)
			return true;
		if (obj == null)
			return false;
		if (getClass() != obj.getClass())
			return false;
		Logro other = (Logro) obj;
		if (fechaConseguido == null) {
			if (other.fechaConseguido != null)
				return false;
		} else if (!fechaConseguido.equals(other.fechaConseguido))
			return false;
		if (fechaModificacion == null) {
			if (other.fechaModificacion != null)
				return false;
		} else if (!fechaModificacion.equals(other.fechaModificacion))
			return false;
		if (id == null) {
			if (other.id != null)
				return false;
		} else if (!id.equals(other.id))
			return false;
		if (tipoVisibilidad == null) {
			if (other.tipoVisibilidad != null)
				return false;
		} else if (!tipoVisibilidad.equals(other.tipoVisibilidad))
			return false;
		return true;
	}

	@Override
	public String toString() {
		return "Logro [id=" + id + ", fechaConseguido=" + fechaConseguido + ", fechaModificacion=" + fechaModificacion
				+ ", tipoVisibilidad=" + tipoVisibilidad + "]";
	}
}
