package es.uva.tfg.geolocalizationgame.resources;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.JoinTable;
import javax.persistence.ManyToMany;
import javax.persistence.ManyToOne;
import javax.persistence.Table;
import javax.persistence.Temporal;
import javax.persistence.TemporalType;
import javax.validation.constraints.NotNull;

import com.fasterxml.jackson.annotation.JsonView;

/**
 * Definicion de la entidad Partida.
 * 
 * @author Cristina Gomez Escribano
 * @version 5.0
 * @since 22/09/2018
 *
 */
@Entity
@Table(name = "partida")
public class Partida implements Serializable {

	
	/**
	 * 
	 */
	private static final long serialVersionUID = 1L;
	
	@Id
	@GeneratedValue(strategy = GenerationType.AUTO)
	@Column(name="ID_PARTIDA", unique = true)
	private Integer idPartida;
	
	@JsonView(DatosUser.GameView.class)
	@NotNull
	@Column(name="PUNTUACION")
	private Double puntuacion;
	
	@NotNull
	@JoinColumn(name="ID_NIVEL_DIFICULTAD", referencedColumnName="ID_NIVEL_DIFICULTAD", nullable=false)
	@ManyToOne(optional=false)
	private NivelDificultad nivelDificultad;
	
	@NotNull
	@JoinColumn(name="ID_MODALIDAD", referencedColumnName="ID_MODALIDAD", nullable=false)
	@ManyToOne(optional=false)
	private ModalidadDeJuego modalidadJuego;
	
	@JsonView(DatosUser.GameView.class)
	@NotNull
	@Column(name="FECHA_PARTIDA")
	@Temporal(TemporalType.TIMESTAMP)
	private Date fechaCreacion;
	
	@ManyToOne
	@JoinColumn(name="ID_JUEGO")
	@NotNull
	private Juego juego;
	
	@JsonView(DatosUser.GameView.class)
	@ManyToOne
	@JoinColumn(name="LOGIN")
	@NotNull
	private Usuario creador;

	@ManyToMany
	@JoinTable(name = "acierto", joinColumns = @JoinColumn(name = "ID_PARTIDA"), inverseJoinColumns = @JoinColumn(name = "ID_PUNTO"))
	private List<PuntoGeografico> puntosAcertados;
	
	@ManyToMany
	@JoinTable(name = "fallo", joinColumns = @JoinColumn(name = "ID_PARTIDA"), inverseJoinColumns = @JoinColumn(name = "ID_PUNTO"))
	private List<PuntoGeografico> puntosFallados;
	
	public Partida() {
		super();
	}

	public Partida(Integer idPartida, Double puntuacion, NivelDificultad nivelDificultad,
			ModalidadDeJuego modalidadJuego, Date fechaCreacion, Juego juego, Usuario creador,
			List<PuntoGeografico> puntosAcertados, List<PuntoGeografico> puntosFallados) {
		super();
		this.idPartida = idPartida;
		this.puntuacion = puntuacion;
		this.nivelDificultad = nivelDificultad;
		this.modalidadJuego = modalidadJuego;
		this.fechaCreacion = fechaCreacion;
		this.juego = juego;
		this.creador = creador;
		this.puntosAcertados = puntosAcertados;
		this.puntosFallados = puntosFallados;
	}

	public Integer getIdPartida() {
		return idPartida;
	}

	public void setIdPartida(Integer idPartida) {
		this.idPartida = idPartida;
	}

	public Double getPuntuacion() {
		return puntuacion;
	}

	public void setPuntuacion(Double puntuacion) {
		this.puntuacion = puntuacion;
	}

	public NivelDificultad getNivelDificultad() {
		return nivelDificultad;
	}

	public void setNivelDificultad(NivelDificultad nivelDificultad) {
		this.nivelDificultad = nivelDificultad;
	}

	public ModalidadDeJuego getModalidadJuego() {
		return modalidadJuego;
	}

	public void setModalidadJuego(ModalidadDeJuego modalidadJuego) {
		this.modalidadJuego = modalidadJuego;
	}

	public Date getFechaCreacion() {
		return fechaCreacion;
	}

	public void setFechaCreacion(Date fechaCreacion) {
		this.fechaCreacion = fechaCreacion;
	}

	public Juego getJuego() {
		return juego;
	}

	public void setJuego(Juego juego) {
		this.juego = juego;
	}

	public Usuario getCreador() {
		return creador;
	}

	public void setCreador(Usuario creador) {
		this.creador = creador;
	}
	
	public List<PuntoGeografico> getPuntosAcertados() {
		return puntosAcertados;
	}

	public void setPuntosAcertados(List<PuntoGeografico> puntosAcertados) {
		this.puntosAcertados = puntosAcertados;
	}

	public List<PuntoGeografico> getPuntosFallados() {
		return puntosFallados;
	}

	public void setPuntosFallados(List<PuntoGeografico> puntosFallados) {
		this.puntosFallados = puntosFallados;
	}

	@Override
	public int hashCode() {
		final int prime = 31;
		int result = 1;
		result = prime * result + ((creador == null) ? 0 : creador.hashCode());
		result = prime * result + ((fechaCreacion == null) ? 0 : fechaCreacion.hashCode());
		result = prime * result + ((idPartida == null) ? 0 : idPartida.hashCode());
		result = prime * result + ((juego == null) ? 0 : juego.hashCode());
		result = prime * result + ((modalidadJuego == null) ? 0 : modalidadJuego.hashCode());
		result = prime * result + ((nivelDificultad == null) ? 0 : nivelDificultad.hashCode());
		result = prime * result + ((puntosAcertados == null) ? 0 : puntosAcertados.hashCode());
		result = prime * result + ((puntosFallados == null) ? 0 : puntosFallados.hashCode());
		result = prime * result + ((puntuacion == null) ? 0 : puntuacion.hashCode());
		return result;
	}

	@Override
	public boolean equals(Object obj) {
		if (this == obj)
			return true;
		if (obj == null)
			return false;
		if (getClass() != obj.getClass())
			return false;
		Partida other = (Partida) obj;
		if (creador == null) {
			if (other.creador != null)
				return false;
		} else if (!creador.equals(other.creador))
			return false;
		if (fechaCreacion == null) {
			if (other.fechaCreacion != null)
				return false;
		} else if (!fechaCreacion.equals(other.fechaCreacion))
			return false;
		if (idPartida == null) {
			if (other.idPartida != null)
				return false;
		} else if (!idPartida.equals(other.idPartida))
			return false;
		if (juego == null) {
			if (other.juego != null)
				return false;
		} else if (!juego.equals(other.juego))
			return false;
		if (modalidadJuego == null) {
			if (other.modalidadJuego != null)
				return false;
		} else if (!modalidadJuego.equals(other.modalidadJuego))
			return false;
		if (nivelDificultad == null) {
			if (other.nivelDificultad != null)
				return false;
		} else if (!nivelDificultad.equals(other.nivelDificultad))
			return false;
		if (puntosAcertados == null) {
			if (other.puntosAcertados != null)
				return false;
		} else if (!puntosAcertados.equals(other.puntosAcertados))
			return false;
		if (puntosFallados == null) {
			if (other.puntosFallados != null)
				return false;
		} else if (!puntosFallados.equals(other.puntosFallados))
			return false;
		if (puntuacion == null) {
			if (other.puntuacion != null)
				return false;
		} else if (!puntuacion.equals(other.puntuacion))
			return false;
		return true;
	}

	@Override
	public String toString() {
		return "Partida [idPartida=" + idPartida + ", puntuacion=" + puntuacion + ", nivelDificultad=" + nivelDificultad
				+ ", modalidadJuego=" + modalidadJuego + ", fechaCreacion=" + fechaCreacion + ", juego=" + juego
				+ ", creador=" + creador + ", puntosAcertados=" + puntosAcertados + ", puntosFallados=" + puntosFallados
				+ "]";
	}
}
