package es.uva.tfg.geolocalizationgame.resources;

import java.io.Serializable;
import java.util.List;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToMany;
import javax.persistence.ManyToOne;
import javax.persistence.Table;
import javax.validation.constraints.NotNull;
import javax.validation.constraints.Size;

import com.fasterxml.jackson.annotation.JsonView;

/**
 * Definicion de la entidad PuntoGeografico.
 * 
 * @author Cristina Gomez Escribano
 * @version 5.0
 * @since 20/10/2018
 *
 */
@Entity
@Table(name = "punto_geografico")
public class PuntoGeografico implements Serializable {

	/**
	 * 
	 */
	private static final long serialVersionUID = 1L;

	@Id
	@GeneratedValue(strategy = GenerationType.AUTO)
	@JsonView(DatosUser.GameView.class)
	@Column(name="ID_PUNTO", unique = true)
	private Integer idPunto;
	
	@JsonView(DatosUser.GameView.class)
	@Column(name="NOMBRE")
	@Size(min = 1, max = 200)
	@NotNull
	private String nombre;
	
	@JsonView(DatosUser.GameView.class)
	@Column(name="LATITUD")
	@NotNull
	private Double latitud;
	
	@JsonView(DatosUser.GameView.class)
	@Column(name="LONGITUD")
	@NotNull
	private Double longitud;
	
	@ManyToOne
	@JoinColumn(name="ID_JUEGO")
	@NotNull
	private Juego juego;
	
	@JsonView(DatosUser.GameView.class)
	@Column(name="PAIS")
	@Size(min = 1, max = 30)
	@NotNull
	private String pais;
	
	@JsonView(DatosUser.GameView.class)
	@Column(name="CONTINENTE")
	@Size(min = 1, max = 20)
	@NotNull
	private String continente;

	@JsonView(DatosUser.GameView.class)
	@NotNull
	@JoinColumn(name="ID_TIPO_PUNTO", referencedColumnName="ID_TIPO_PUNTO", nullable=false)
	@ManyToOne(optional=false)
	private TipoPunto idTipoPunto;
	
	@ManyToMany(mappedBy = "puntosConseguidos")
	private List<Usuario> usuarios;
	
	@ManyToMany(mappedBy = "puntosAcertados")
	private List<Partida> partidasPuntoAcertado;
	
	@ManyToMany(mappedBy = "puntosFallados")
	private List<Partida> partidasPuntoFallado;

	public PuntoGeografico() {
		super();
	}

	public PuntoGeografico(Integer idPunto, String nombre, Double latitud, Double longitud, Juego juego, String pais,
			String continente, TipoPunto idTipoPunto) {
		super();
		this.idPunto = idPunto;
		this.nombre = nombre;
		this.latitud = latitud;
		this.longitud = longitud;
		this.juego = juego;
		this.pais = pais;
		this.continente = continente;
		this.idTipoPunto = idTipoPunto;
	}

	public Integer getIdPunto() {
		return idPunto;
	}

	public void setIdPunto(Integer idPunto) {
		this.idPunto = idPunto;
	}

	public String getNombre() {
		return nombre;
	}

	public void setNombre(String nombre) {
		this.nombre = nombre;
	}

	public Double getLatitud() {
		return latitud;
	}

	public void setLatitud(Double latitud) {
		this.latitud = latitud;
	}

	public Double getLongitud() {
		return longitud;
	}

	public void setLongitud(Double longitud) {
		this.longitud = longitud;
	}

	public Juego getJuego() {
		return juego;
	}

	public void setJuego(Juego juego) {
		this.juego = juego;
	}

	public String getPais() {
		return pais;
	}

	public void setPais(String pais) {
		this.pais = pais;
	}

	public String getContinente() {
		return continente;
	}

	public void setContinente(String continente) {
		this.continente = continente;
	}

	public TipoPunto getIdTipoPunto() {
		return idTipoPunto;
	}

	public void setIdTipoPunto(TipoPunto idTipoPunto) {
		this.idTipoPunto = idTipoPunto;
	}

	public List<Usuario> getUsuarios() {
		return usuarios;
	}

	public void setUsuarios(List<Usuario> usuarios) {
		this.usuarios = usuarios;
	}

	public List<Partida> getPartidasPuntoAcertado() {
		return partidasPuntoAcertado;
	}

	public void setPartidasPuntoAcertado(List<Partida> partidasPuntoAcertado) {
		this.partidasPuntoAcertado = partidasPuntoAcertado;
	}

	public List<Partida> getPartidasPuntoFallado() {
		return partidasPuntoFallado;
	}

	public void setPartidasPuntoFallado(List<Partida> partidasPuntoFallado) {
		this.partidasPuntoFallado = partidasPuntoFallado;
	}

	@Override
	public int hashCode() {
		final int prime = 31;
		int result = 1;
		result = prime * result + ((continente == null) ? 0 : continente.hashCode());
		result = prime * result + ((idPunto == null) ? 0 : idPunto.hashCode());
		result = prime * result + ((idTipoPunto == null) ? 0 : idTipoPunto.hashCode());
		result = prime * result + ((juego == null) ? 0 : juego.hashCode());
		result = prime * result + ((latitud == null) ? 0 : latitud.hashCode());
		result = prime * result + ((longitud == null) ? 0 : longitud.hashCode());
		result = prime * result + ((nombre == null) ? 0 : nombre.hashCode());
		result = prime * result + ((pais == null) ? 0 : pais.hashCode());
		return result;
	}

	@Override
	public boolean equals(Object obj) {
		if (this == obj)
			return true;
		if (obj == null)
			return false;
		if (getClass() != obj.getClass())
			return false;
		PuntoGeografico other = (PuntoGeografico) obj;
		if (continente == null) {
			if (other.continente != null)
				return false;
		} else if (!continente.equals(other.continente))
			return false;
		if (idPunto == null) {
			if (other.idPunto != null)
				return false;
		} else if (!idPunto.equals(other.idPunto))
			return false;
		if (idTipoPunto == null) {
			if (other.idTipoPunto != null)
				return false;
		} else if (!idTipoPunto.equals(other.idTipoPunto))
			return false;
		if (juego == null) {
			if (other.juego != null)
				return false;
		} else if (!juego.equals(other.juego))
			return false;
		if (latitud == null) {
			if (other.latitud != null)
				return false;
		} else if (!latitud.equals(other.latitud))
			return false;
		if (longitud == null) {
			if (other.longitud != null)
				return false;
		} else if (!longitud.equals(other.longitud))
			return false;
		if (nombre == null) {
			if (other.nombre != null)
				return false;
		} else if (!nombre.equals(other.nombre))
			return false;
		if (pais == null) {
			if (other.pais != null)
				return false;
		} else if (!pais.equals(other.pais))
			return false;
		return true;
	}

	@Override
	public String toString() {
		return "PuntoGeografico [idPunto=" + idPunto + ", nombre=" + nombre + ", latitud=" + latitud + ", longitud="
				+ longitud + ", juego=" + juego + ", pais=" + pais + ", continente=" + continente + ", idTipoPunto="
				+ idTipoPunto + "]";
	}
}
