package es.uva.tfg.geolocalizationgame.resources;

import java.io.Serializable;
import java.util.Date;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.Table;
import javax.persistence.Temporal;
import javax.persistence.TemporalType;
import javax.validation.constraints.NotNull;

import com.fasterxml.jackson.annotation.JsonView;

/**
 * Definicion de la entidad SolcitudAmistad.
 * 
 * @author Cristina Gomez Escribano
 * @version 5.0
 * @since 30/08/2018
 *
 */
@Entity
@Table(name = "solicitud_amistad")
public class SolicitudAmistad implements Serializable {

	/**
	 * 
	 */
	private static final long serialVersionUID = 1L;

	@Id
	@GeneratedValue(strategy = GenerationType.AUTO)
	@Column(name="ID_SOLICITUD_AMISTAD", unique = true)
	@JsonView(DatosUser.Basic.class)
	private Integer idSolicitudAmistad;
	
	@NotNull
	@JoinColumn(name="ID_ESTADO_SOLICITUD", referencedColumnName="ID_ESTADO_SOLICITUD", nullable=false)
	@JsonView(DatosUser.Basic.class)
	@ManyToOne(optional=false)
	private EstadoSolicitudAmistad estadoSolicitud;
	
	@NotNull
	@Column(name="FECHA_ENVIO")
	@Temporal(TemporalType.TIMESTAMP)
	@JsonView(DatosUser.Basic.class)
	private Date fecha;
	
	@NotNull
	@Column(name="FECHA_MODIFICACION")
	@Temporal(TemporalType.TIMESTAMP)
	@JsonView(DatosUser.Basic.class)
	private Date fechaModificacion;
	
	//@JsonIdentityInfo(generator = ObjectIdGenerators.PropertyGenerator.class, property="login")
	//@JsonIdentityReference(alwaysAsId = true)
	@ManyToOne(optional=false)
	@JoinColumn(name="EMISOR", referencedColumnName="LOGIN")
	@JsonView(DatosUser.WithSolicitudesRecibidas.class)
	private Usuario emisor;
	
	//@JsonIdentityInfo(generator = ObjectIdGenerators.PropertyGenerator.class, property="login")
	//@JsonIdentityReference(alwaysAsId = true)
	@ManyToOne(optional=false)
	@JsonView(DatosUser.WithSolicitudesEnviadas.class)
	@JoinColumn(name="RECEPTOR", referencedColumnName="LOGIN")
	private Usuario receptor;

	
	public SolicitudAmistad() {
		super();
	}


	public SolicitudAmistad(Integer idSolicitudAmistad, EstadoSolicitudAmistad estadoSolicitud, Date fecha,
			Date fechaModificacion, Usuario emisor, Usuario receptor) {
		super();
		this.idSolicitudAmistad = idSolicitudAmistad;
		this.estadoSolicitud = estadoSolicitud;
		this.fecha = fecha;
		this.fechaModificacion = fechaModificacion;
		this.emisor = emisor;
		this.receptor = receptor;
	}


	public Integer getIdSolicitudAmistad() {
		return idSolicitudAmistad;
	}


	public void setIdSolicitudAmistad(Integer idSolicitudAmistad) {
		this.idSolicitudAmistad = idSolicitudAmistad;
	}


	public EstadoSolicitudAmistad getEstadoSolicitud() {
		return estadoSolicitud;
	}


	public void setEstadoSolicitud(EstadoSolicitudAmistad estadoSolicitud) {
		this.estadoSolicitud = estadoSolicitud;
	}


	public Date getFecha() {
		return fecha;
	}


	public void setFecha(Date fecha) {
		this.fecha = fecha;
	}


	public Date getFechaModificacion() {
		return fechaModificacion;
	}


	public void setFechaModificacion(Date fechaModificacion) {
		this.fechaModificacion = fechaModificacion;
	}


	public Usuario getEmisor() {
		return emisor;
	}


	public void setEmisor(Usuario emisor) {
		this.emisor = emisor;
	}


	public Usuario getReceptor() {
		return receptor;
	}


	public void setReceptor(Usuario receptor) {
		this.receptor = receptor;
	}


	@Override
	public int hashCode() {
		final int prime = 31;
		int result = 1;
		result = prime * result + ((emisor == null) ? 0 : emisor.hashCode());
		result = prime * result + ((estadoSolicitud == null) ? 0 : estadoSolicitud.hashCode());
		result = prime * result + ((fecha == null) ? 0 : fecha.hashCode());
		result = prime * result + ((fechaModificacion == null) ? 0 : fechaModificacion.hashCode());
		result = prime * result + ((idSolicitudAmistad == null) ? 0 : idSolicitudAmistad.hashCode());
		result = prime * result + ((receptor == null) ? 0 : receptor.hashCode());
		return result;
	}


	@Override
	public boolean equals(Object obj) {
		if (this == obj)
			return true;
		if (obj == null)
			return false;
		if (getClass() != obj.getClass())
			return false;
		SolicitudAmistad other = (SolicitudAmistad) obj;
		if (emisor == null) {
			if (other.emisor != null)
				return false;
		} else if (!emisor.equals(other.emisor))
			return false;
		if (estadoSolicitud == null) {
			if (other.estadoSolicitud != null)
				return false;
		} else if (!estadoSolicitud.equals(other.estadoSolicitud))
			return false;
		if (fecha == null) {
			if (other.fecha != null)
				return false;
		} else if (!fecha.equals(other.fecha))
			return false;
		if (fechaModificacion == null) {
			if (other.fechaModificacion != null)
				return false;
		} else if (!fechaModificacion.equals(other.fechaModificacion))
			return false;
		if (idSolicitudAmistad == null) {
			if (other.idSolicitudAmistad != null)
				return false;
		} else if (!idSolicitudAmistad.equals(other.idSolicitudAmistad))
			return false;
		if (receptor == null) {
			if (other.receptor != null)
				return false;
		} else if (!receptor.equals(other.receptor))
			return false;
		return true;
	}


	@Override
	public String toString() {
		return "SolicitudAmistad [idSolicitudAmistad=" + idSolicitudAmistad + ", estadoSolicitud=" + estadoSolicitud
				+ ", fecha=" + fecha + ", fechaModificacion=" + fechaModificacion + ", emisor=" + emisor + ", receptor="
				+ receptor + "]";
	}

	
}
