package es.uva.tfg.geolocalizationgame.resources;

import java.io.Serializable;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.Table;
import javax.validation.constraints.NotNull;

import com.fasterxml.jackson.annotation.JsonView;

/**
 * Definicion de la entidad TipoLogro.
 * 
 * @author Cristina Gomez Escribano
 * @version 2.0
 * @since 11/11/2018
 *
 */
@Entity
@Table(name = "tipo_logro")
public class TipoLogro implements Serializable {

	/**
	 * 
	 */
	private static final long serialVersionUID = 1L;

	@Id
	@Column(name="ID_TIPO_LOGRO", unique = true)
	@JsonView(DatosUser.PrivateProfile.class)
	private Integer idTipoLogro;
	
	@Column(name="LOGRO")
	@NotNull
	@JsonView(DatosUser.PrivateProfile.class)
	private String logro;
	
	@Column(name="DESCRIPCION")
	@NotNull
	@JsonView(DatosUser.PrivateProfile.class)
	private String descripcion;
	
	@Column(name="PUNTOS_A_CONSEGUIR")
	@NotNull
	@JsonView(DatosUser.PrivateProfile.class)
	private Integer puntosAConseguir;
	
	@JoinColumn(name="ID_TIPO_PUNTO", referencedColumnName="ID_TIPO_PUNTO")
	@ManyToOne
	@JsonView(DatosUser.PrivateProfile.class)
	private TipoPunto idTipoPunto;
	
	@Column(name="CONTINENTE")
	@JsonView(DatosUser.PrivateProfile.class)
	private String continente;
	
	@Column(name="PAIS")
	@JsonView(DatosUser.PrivateProfile.class)
	private String pais;

	public TipoLogro() {
		super();
	}

	public TipoLogro(Integer idLogro, String logro, String descripcion, Integer puntosAConseguir, TipoPunto idTipoPunto,
			String continente, String pais) {
		super();
		this.idTipoLogro = idLogro;
		this.logro = logro;
		this.descripcion = descripcion;
		this.puntosAConseguir = puntosAConseguir;
		this.idTipoPunto = idTipoPunto;
		this.continente = continente;
		this.pais = pais;
	}

	public Integer getIdLogro() {
		return idTipoLogro;
	}

	public void setIdLogro(Integer idLogro) {
		this.idTipoLogro = idLogro;
	}

	public String getLogro() {
		return logro;
	}

	public void setLogro(String logro) {
		this.logro = logro;
	}

	public String getDescripcion() {
		return descripcion;
	}

	public void setDescripcion(String descripcion) {
		this.descripcion = descripcion;
	}

	public Integer getPuntosAConseguir() {
		return puntosAConseguir;
	}

	public void setPuntosAConseguir(Integer puntosAConseguir) {
		this.puntosAConseguir = puntosAConseguir;
	}

	public TipoPunto getIdTipoPunto() {
		return idTipoPunto;
	}

	public void setIdTipoPunto(TipoPunto idTipoPunto) {
		this.idTipoPunto = idTipoPunto;
	}

	public String getContinente() {
		return continente;
	}

	public void setContinente(String continente) {
		this.continente = continente;
	}

	public String getPais() {
		return pais;
	}

	public void setPais(String pais) {
		this.pais = pais;
	}

	@Override
	public int hashCode() {
		final int prime = 31;
		int result = 1;
		result = prime * result + ((continente == null) ? 0 : continente.hashCode());
		result = prime * result + ((descripcion == null) ? 0 : descripcion.hashCode());
		result = prime * result + ((idTipoLogro == null) ? 0 : idTipoLogro.hashCode());
		result = prime * result + ((idTipoPunto == null) ? 0 : idTipoPunto.hashCode());
		result = prime * result + ((logro == null) ? 0 : logro.hashCode());
		result = prime * result + ((pais == null) ? 0 : pais.hashCode());
		result = prime * result + ((puntosAConseguir == null) ? 0 : puntosAConseguir.hashCode());
		return result;
	}

	@Override
	public boolean equals(Object obj) {
		if (this == obj)
			return true;
		if (obj == null)
			return false;
		if (getClass() != obj.getClass())
			return false;
		TipoLogro other = (TipoLogro) obj;
		if (continente == null) {
			if (other.continente != null)
				return false;
		} else if (!continente.equals(other.continente))
			return false;
		if (descripcion == null) {
			if (other.descripcion != null)
				return false;
		} else if (!descripcion.equals(other.descripcion))
			return false;
		if (idTipoLogro == null) {
			if (other.idTipoLogro != null)
				return false;
		} else if (!idTipoLogro.equals(other.idTipoLogro))
			return false;
		if (idTipoPunto == null) {
			if (other.idTipoPunto != null)
				return false;
		} else if (!idTipoPunto.equals(other.idTipoPunto))
			return false;
		if (logro == null) {
			if (other.logro != null)
				return false;
		} else if (!logro.equals(other.logro))
			return false;
		if (pais == null) {
			if (other.pais != null)
				return false;
		} else if (!pais.equals(other.pais))
			return false;
		if (puntosAConseguir == null) {
			if (other.puntosAConseguir != null)
				return false;
		} else if (!puntosAConseguir.equals(other.puntosAConseguir))
			return false;
		return true;
	}

	@Override
	public String toString() {
		return "Logro [idLogro=" + idTipoLogro + ", logro=" + logro + ", descripcion=" + descripcion + ", puntosAConseguir="
				+ puntosAConseguir + ", idTipoPunto=" + idTipoPunto + ", continente=" + continente + ", pais=" + pais
				+ "]";
	}
}
