package es.uva.tfg.geolocalizationgame.services;

import java.util.List;

import javax.validation.Valid;

import es.uva.tfg.geolocalizationgame.resources.Comentario;
import es.uva.tfg.geolocalizationgame.resources.Juego;
import es.uva.tfg.geolocalizationgame.resources.Usuario;

/**
 * Reprensenta la interfaz de servicio para la entidad Comentario
 * 
 * @author Cristina Gomez Escribano
 * @version 3.0
 * @since 18/12/2019
 *
 */
public interface ComentarioService {

	/**
	 * Devuelve un comentario con los datos que se le pasan como parametro.
	 * 
	 * @param descripcion
	 * @param usuario
	 * @param juego
	 * @return Comentario
	 */
	Comentario crearComentario(String descripcion, @Valid Usuario usuario, @Valid Juego juego);

	/**
	 * Realiza la llamada para persistir el comentario.
	 * 
	 * @param comentario
	 */
	void saveComentario(@Valid Comentario comentario);
	
	/**
	 * Devuelve los comentarios de un juego.
	 * 
	 * @param juego
	 * @return List<Comentario>
	 */
	List<Comentario> obtenerComentariosByJuego(@Valid Juego juego);

	/**
	 * Devuelve un comentario por id.
	 * 
	 * @param idComentario
	 * @return Comentario
	 */
	Comentario obtenerComentarioById(Integer idComentario);

	/**
	 * Realiza la llamada para eliminar un comentario del sistema.
	 * 
	 * @param comentario
	 */
	void deleteComentario(@Valid Comentario comentario);

	/**
	 * Actualiza un comentario en el sistema.
	 * 
	 * @param comentario
	 * @param descripcion
	 */
	void updateComentario(@Valid Comentario comentario, String descripcion);

}
