package es.uva.tfg.geolocalizationgame.services;

import java.util.Date;
import java.util.List;

import javax.validation.Valid;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import es.uva.tfg.geolocalizationgame.persistence.ComentarioRepository;
import es.uva.tfg.geolocalizationgame.resources.Comentario;
import es.uva.tfg.geolocalizationgame.resources.Juego;
import es.uva.tfg.geolocalizationgame.resources.Usuario;

/**
 * Implementa el servicio para la entidad Comentario
 * 
 * @author Cristina Gomez Escribano
 * @version 3.0
 * @since 18/12/2019
 *
 */
@Service
public class ComentarioServiceImpl implements ComentarioService{

	@Autowired
	private ComentarioRepository comentarioRepository;
	
	@Override
	public Comentario crearComentario(String descripcion, @Valid Usuario usuario, @Valid Juego juego) {
		Comentario comentario = new Comentario();
		comentario.setCreador(usuario);
		comentario.setDescripcion(descripcion);
		comentario.setFechaCreacion(new Date());
		comentario.setFechaModificacion(new Date());
		comentario.setJuego(juego);
		return comentario;
	}

	@Override
	public void saveComentario(@Valid Comentario comentario) {
		comentarioRepository.saveAndFlush(comentario);
	}

	@Override
	public List<Comentario> obtenerComentariosByJuego(@Valid Juego juego) {
		return comentarioRepository.getComentariosByJuego(juego);
	}

	@Override
	public Comentario obtenerComentarioById(Integer idComentario) {
		return comentarioRepository.findOne(idComentario);
	}

	@Override
	public void deleteComentario(Comentario comentario) {
		comentarioRepository.delete(comentario);
		
	}

	@Override
	public void updateComentario(Comentario comentario, String descripcion) {
		comentario.setFechaModificacion(new Date());
		comentario.setDescripcion(descripcion);
	}

}
