package es.uva.tfg.geolocalizationgame.services;

import java.util.List;

import javax.validation.Valid;

import es.uva.tfg.geolocalizationgame.exceptions.TipoVisibilidadNotFoundException;
import es.uva.tfg.geolocalizationgame.resources.Logro;
import es.uva.tfg.geolocalizationgame.resources.TipoLogro;
import es.uva.tfg.geolocalizationgame.resources.Usuario;

/**
 * Definición de las firmas de lo métodos disponibles en el servicio para las transacciones de la entidad logro
 * 
 * @author Cristina Gómez Escribano
 * @version 2.0
 * @since 16/09/2018
 *
 */
public interface LogroService {

	/**
	 * Devuelve un logro por id.
	 * 
	 * @param usuario
	 * @param tipoLogro
	 * @return Logro
	 */
	Logro obtenerLogroById(@Valid Usuario usuario, @Valid TipoLogro tipoLogro);

	/**
	 * Actualiza la visibilidad de un logro.
	 * 
	 * @param logro
	 * @param visibilidad
	 * @return boolean
	 */
	boolean actualizarVisibilidad(@Valid Logro logro, Integer visibilidad);

	/**
	 * Realiza la llamada para actualizar un logro en el sistema.
	 * 
	 * @param logro
	 * @return Logro
	 */
	Logro updateLogro(Logro logro);

	/**
	 * Obtiene los logros nuevos conseguidos por un usuario.
	 * 
	 * @param usuario
	 * @return
	 * @throws TipoVisibilidadNotFoundException
	 */
	List<Logro> obtenerLogrosNuevos(@Valid Usuario usuario) throws TipoVisibilidadNotFoundException;
	
	/**
	 * Realiza la llamada para persistir un logro en el sistema.
	 * 
	 * @param logro
	 */
	void saveLogro(@Valid Logro logro);

}
