package es.uva.tfg.geolocalizationgame.services;

import java.util.List;

import javax.validation.Valid;

import es.uva.tfg.geolocalizationgame.resources.SolicitudAmistad;

/**
 * Implementa la clase de servicio para la entidad Solicitud de amistad.
 * 
 * @author Cristina Gómez Escribano
 * @version 1.0
 * @since 28/08/2018
 *
 */
public interface SolicitudAmistadService {

	/**
	 * Servicio que crea una solicitud de amistad en la base de datos
	 * 
	 * @param solicitud
	 * @return true or false 
	 */
	public boolean createSolicitudAmistad(String emisor, String receptor);

	/**
	 * Servicio que devuelve todas las solicitudes recibidas de un usuario por login
	 * @param login
	 * @return
	 */
	public List<SolicitudAmistad> obtenerSolicitudByReceptor(String login);

	/**
	 * Comprueba si existe una solicitud en estado pendiente
	 * @param json
	 * @return true o false
	 */
	public boolean exitsSolicitud(String emisor, String receptor);

	/**
	 * Devuelve las solicitudes enviadas por un usuario en un estado concreto.
	 * 
	 * @param login
	 * @param estado
	 * @return List<SolicitudAmistad>
	 */
	public List<SolicitudAmistad> obtenerSolicitudesEnviadasByEstado(String login, String estado);
	
	/**
	 * Devuelve las solicitudes recibidas por un usuario en un estado concreto.
	 * 
	 * @param login
	 * @param estado
	 * @return List<SolicitudAmistad>
	 */
	public List<SolicitudAmistad> obtenerSolicitudesRecibidasByEstado(String login, String estado);

	/**
	 * Devuelve una solicitud por identificador
	 * @param idSolicitud
	 * @return SolicitudAmistad
	 */
	public SolicitudAmistad obtenerSolicitudById(Integer idSolicitud);

	/**
	 * Actualiza el estado de una solicitud
	 * @param solicitud
	 * @param estado
	 * @return true o false
	 */
	public boolean actualizarEstado(@Valid SolicitudAmistad solicitud, String estado);

	/**
	 * Actualiza la solicitud en la base de datos
	 * @param solicitud
	 * @return SolicitudAmistad
	 */
	public SolicitudAmistad updateSolicitud(@Valid SolicitudAmistad solicitud);
}
