package es.uva.tfg.geolocalizationgame.services;

import java.util.Date;
import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import es.uva.tfg.geolocalizationgame.persistence.SolicitudAmistadRepository;
import es.uva.tfg.geolocalizationgame.resources.EstadoSolicitudAmistad;
import es.uva.tfg.geolocalizationgame.resources.SolicitudAmistad;
import es.uva.tfg.geolocalizationgame.resources.Usuario;

/**
 * Implementación del servicio de Solicitud de amistad.
 * 
 * @author Cristina Gómez Escribano
 * @version 1.0
 * @since 28/08/2018
 *
 */
@Service
public class SolicitudAmistadServiceImpl implements SolicitudAmistadService {

	@Autowired
	public SolicitudAmistadRepository solicitudRepository;

	@Autowired
	public UserService userService;

	@Autowired
	public EstadoSolicitudAmistadService estadoService;

	@Override
	public boolean createSolicitudAmistad(String emisor, String receptor) {
		boolean creado=false;
		SolicitudAmistad solicitudAmistad = new SolicitudAmistad();
		Usuario usuarioEmisor = userService.obtenerUsuarioByLogin(emisor);
		Usuario usuarioReceptor = userService.obtenerUsuarioByLogin(receptor);
		EstadoSolicitudAmistad estado = estadoService.obtenerEstadoByNombre("Pendiente");
		if (usuarioEmisor!=null && usuarioReceptor!=null && estado!=null) {//si tengo todos los datos
			solicitudAmistad.setEmisor(usuarioEmisor);
			solicitudAmistad.setReceptor(usuarioReceptor);
			solicitudAmistad.setEstadoSolicitud(estado);
			solicitudAmistad.setFecha(new Date());
			solicitudAmistad.setFechaModificacion(new Date());
			solicitudRepository.save(solicitudAmistad);
			creado=true;
		}
		return creado;
	}

	@Override
	public List<SolicitudAmistad> obtenerSolicitudByReceptor(String login) {
		return solicitudRepository.getSolicitudes(login);
	}

	@Override
	public boolean exitsSolicitud(String emisor, String receptor) {
		boolean existSolicitud = false;
		EstadoSolicitudAmistad estado = estadoService.obtenerEstadoByNombre("Pendiente");
		if (estado != null) {// ha devuelto el estado
			if (solicitudRepository.obtenerSolicitudByEmisorReceptorEstado(emisor, receptor,
					estado.getIdEstadoSolicitud()) != null) {// no existe la solicitud
				existSolicitud = true;
			}
		}
		return existSolicitud;
	}

	@Override
	public List<SolicitudAmistad> obtenerSolicitudesEnviadasByEstado(String login,
			String estado) {
		return solicitudRepository.obtenerSolicitudesEnviadasByEstado(userService.obtenerUsuarioByLogin(login), estadoService.obtenerEstadoByNombre(estado));
	}
	
	@Override
	public List<SolicitudAmistad> obtenerSolicitudesRecibidasByEstado(String login,
			String estado) {
		return solicitudRepository.obtenerSolicitudesRecibidasByEstado(userService.obtenerUsuarioByLogin(login), estadoService.obtenerEstadoByNombre(estado));
	}

	@Override
	public SolicitudAmistad obtenerSolicitudById(Integer idSolicitud) {
		return solicitudRepository.findOne(idSolicitud);
	}

	@Override
	public boolean actualizarEstado(SolicitudAmistad solicitud, String estado) {
		boolean update=false;
		EstadoSolicitudAmistad estadoSolicitud=estadoService.obtenerEstadoByNombre(estado);
		if(estadoSolicitud!=null) {//encuentra el estado
			solicitud.setEstadoSolicitud(estadoSolicitud);
			solicitud.setFechaModificacion(new Date());
			update=true;
		}
		return update;
	}

	@Override
	public SolicitudAmistad updateSolicitud(SolicitudAmistad solicitud) {
		return solicitudRepository.saveAndFlush(solicitud);
	}

}
