package es.uva.tfg.geolocalizationgame.services;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.util.stream.Collectors;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.core.authority.SimpleGrantedAuthority;
import org.springframework.security.core.userdetails.User;
import org.springframework.security.core.userdetails.UserDetails;
import org.springframework.security.core.userdetails.UserDetailsService;
import org.springframework.security.core.userdetails.UsernameNotFoundException;
import org.springframework.stereotype.Service;

import es.uva.tfg.geolocalizationgame.persistence.UsuarioRepository;
import es.uva.tfg.geolocalizationgame.resources.Usuario;

/**
 * Servicio que comprueba si un usuario se encuentra registrado en la aplicacion
 * 
 * @author Cristina Gómez Escribano
 *
 */
@Service
public class UserDetailsServiceImpl implements UserDetailsService {

	@Autowired
	private UsuarioRepository usuarioRepository;

	@Override
	public UserDetails loadUserByUsername(String login) throws UsernameNotFoundException {
		Usuario user = usuarioRepository.findOne(login);

		if (user != null) {// el usuario está en la BBDD
			List<String> roles = new ArrayList<>(Arrays.asList("USER"));//se le agrega el rol USER, si tuvieramos roles, se traeria de la BBDD
			List<SimpleGrantedAuthority> auths = roles.stream().map(rol -> new SimpleGrantedAuthority(rol))
					.collect(Collectors.toList());
			return new User(user.getLogin(), user.getPassword(), auths);
		} else {
			throw new UsernameNotFoundException("User "+login+" not found.");
		}

	}

}
