/**
 * Controla la pagina principal de la aplicacion. Incluye la configuracion de idiomas y seleccion o el enrutamiento
 */
var app = angular.module('appGeolocalizationGame', ["pascalprecht.translate","tmh.dynamicLocale", "ngSanitize", "ngRoute"]);

app.config(["$routeProvider", "$locationProvider", "$translateProvider", "tmhDynamicLocaleProvider", function ($routeProvider, $locationProvider, $translateProvider, tmhDynamicLocaleProvider){
	$locationProvider.hashPrefix('');
	
	$routeProvider
	.when('/register',
        {
            templateUrl: 'templates/registro.html',
            controller: 'RegistroController'
        })
	     .when('/portada',
	    {
	    	templateUrl: 'templates/portada.html',
	    	controller: 'PortadaController'
	    })
    .when('/login',
    {
        templateUrl: 'templates/login.html',
        controller: 'LoginController'
    })
    .when('/home',
        {
            templateUrl: 'templates/home.html',
            controller: 'HomeController'
        })
    .when('/home/newGame',
    {
    	templateUrl: 'templates/crearJuego.html',
    	controller: 'CrearJuegoController'
    })
    .when('/home/datosPersonales',
    {
    	templateUrl: 'templates/datosPersonales.html',
    	controller: 'DatosPersonalesController'
    })
    .when('/home/resultSearch',
    {
    	templateUrl: 'templates/resultadoBusqueda.html',
    	controller: 'ResultadoBusquedaController'
    })
    .when('/home/users/:userLogin',
    {
    	templateUrl: 'templates/perfilUsuario.html',
    	controller: 'PerfilUsuarioController'
    })
    .when('/home/notifications',
    {
    	templateUrl: 'templates/notificaciones.html',
    	controller: 'NotificacionesController'
    })
     .when('/home/friends',
    {
    	templateUrl: 'templates/listaAmigos.html',
    	controller: 'ListaAmigosController'
    })
    .when('/home/logros',
    {
    	templateUrl: 'templates/listaLogros.html',
    	controller: 'ListaLogrosController'
    })
    .when('/home/juegos',
    {
    	templateUrl: 'templates/listaJuegos.html',
    	controller: 'ListaJuegosController'
    })
    .when('/home/juegos/:idJuego',
    {
    	templateUrl: 'templates/juego.html',
    	controller: 'JuegoController'
    })
    .when('/home/juegos/:idJuego/play',
    {
    	templateUrl: 'templates/partida.html',
    	controller: 'PartidaController'
    })
     .when('/help',
    {
    	templateUrl: 'templates/ayuda.html',
    	controller: 'AyudaController'
    })
     .when('/home/help',
    {
    	templateUrl: 'templates/ayuda.html',
    	controller: 'AyudaController'
    })
    .otherwise({
    	redirectTo: '/portada'
    });
	
	$locationProvider.html5Mode(true);
	
	/**
	 * Seleccion de idioma segun el navegador
	 */
	$translateProvider.preferredLanguage(navigator.language);
	$translateProvider.registerAvailableLanguageKeys(["en", "es"], {
		"en-*":"en",
		"es-*":"es"
	});
	//ruta de carga de los archivos con los textos segun idioma
	$translateProvider.useStaticFilesLoader({
		prefix:"translations/",
		suffix:".json"
	});
	
	$translateProvider.useSanitizeValueStrategy('sanitizeParameters');
	tmhDynamicLocaleProvider.localeLocationPattern("lib/angular-locale_{{locale}}.js");
}]);

function scrollToElement (elemento) {
    $('html, body').animate({
        scrollTop: $(elemento).offset().top - 70
    }, 1000);
}

function scrollToTop () {
    $('html, body').animate({
        scrollTop: 0
    }, 1000);
}
function scrollToTopNoAnimated(){
	$('html, body').scrollTop(0);
}

function scrollToTopModal(modal){
	$(modal).animate({
	    scrollTop: 0
	}, 1000);
}


  
app.controller('AppController', function($scope, $rootScope, $http) {
	$scope.$on('LOAD',function(){
		console.log("LOAD");
		$rootScope.loading=true;
	});
	$scope.$on('UNLOAD',function(){
		console.log("UNLOAD");
		$rootScope.loading=false;
	});
});

/**
 * Traducciones locales de fecha, hora y monedas, segun idioma seleccionado
 */
app.run(["$window", "$translate", "tmhDynamicLocale", function ($window, $translate, tmhDynamicLocale){
	var language;
	if(localStorage.getItem("idioma")){
		language=localStorage.getItem("idioma");
	}else{
		language = ($window.navigator.userLanguage || $window.navigator.language).indexOf("en") == 0 ? "en-us":"es-es";
	}
	$translate.use(language);
	tmhDynamicLocale.set(language);
}]);