/**
 * Controlador para el mapa
 */
app.controller('MapaController', function ($scope, $rootScope, $translate, $compile, $http, $location, tmhDynamicLocale, MapaService) {
	
  var map;
  var tileLayer;
  $rootScope.portada=false;
  var markers=[];
  var markersLocalizar=[];
  var bounds;
  $scope.si=false;
  $scope.date=new Date();
  $scope.textSearch=null;
  $scope.notFoundPoint=false;
  $rootScope.searchPointKo=false;
  $scope.jugar=false;
  comprobarJugar();
  if($rootScope.crearJuegoMapa || $scope.jugar){//si carga el mapa para jugar o para crearlo, inicializamos el mapa
	  initMap();
	  $rootScope.crearJuegoMapa=false;
  }
  $scope.event=undefined;
  $scope.eventPrev=undefined;
  $scope.markerPrev=undefined;
  $scope.markerPrevPrev=undefined;
  var popUpContent="";
  var featureGroup;
  var featureGroupJugarLocalizar;
  
 /**
  * Comprueba si se esta jugando para mostrar unos elementos u otros en la vista
  */
  function comprobarJugar(){
	  if($location.path().includes("play")){
		  $scope.jugar=true;
	  }
  };
  
  /**
   * Realiza la llamada al servicio para buscar el punto del texto introducido
   */
  $scope.buscarPunto = function() {
	  	if (!$.isEmptyObject(markers)) {
	  		eliminarMarcadores();
	  	};
		MapaService.obtenerDirecciones($scope.textSearch)
		.then(function success(response){
			if(response.length!==0){//tiene datos, se recorren
				mostrarResultado(response);
				$scope.notFoundPoint=false;
			}else{
				$scope.notFoundPoint=true;
			}
		$scope.textSearch="";
		$rootScope.searchPointKo=false;
		},function error(error){
			$rootScope.searchPointKo=true;
			$scope.textSearch="";
			scrollToTop();
		});
	};
	
	/**
	 * Recorre los resultados obtenidos al buscar un punto
	 */
	function mostrarResultado(resultadoBusqueda) {
		featureGroup = L.featureGroup().addTo(map).on("click", mostrarPopUp);
	    for (var i = 0; i < resultadoBusqueda.length; i++) {
	      var place = resultadoBusqueda[i];
	      createMarker(resultadoBusqueda[i]);
	    }	  
	}
	
	/**
	 * Crea un marcador en el mapa con un popup
	 */
	function createMarker(place) {
		popUpContent="<div class='col-12 font-18 no-padding'>";
		popUpContent=popUpContent+"<h5>{{'label.selectPoint'|translate}}</h5><div class='col-12'><span class='font-16 bold'>{{'label.name'|translate}} </span><span class='font-14'>"+place.display_name+"</span></div>";
		popUpContent=popUpContent+"<button type='button' class='col-12 btn btn-primary margin-top-15' ng-click='closePopUp(); $parent.openModalAddPoint(place);'>{{'button.addPoint'|translate}}</button>", 
		linkFunction=$compile(angular.element(popUpContent)),
		newScope=$scope.$new();
		newScope.place=place;
		

		var iconPlace=getIconByType(place.type);
		var marker = L.marker([place.lat, place.lon], {icon:iconPlace}).addTo(featureGroup).bindPopup(linkFunction(newScope)[0]);
		map.setView(new L.LatLng(place.lat, place.lon), 8);
		markers.push(marker);
		popUpContent="";
	}
	
	$scope.closePopUp = function(){
		map.closePopup();
	}
	
	/**
	 * Obtiene un icono dependiendo del tipo del punto encontrado
	 */
	function getIconByType(tipo){
		var icon;
		if(tipo==="administrative"|| tipo==="city" || tipo==="continent" || tipo==="politico"){//politico
			icon=L.AwesomeMarkers.icon({icon: 'university', prefix: 'fa', markerColor: 'gray'});
		}else if(tipo==="river" || tipo==="water" || tipo==="sea" || tipo==="ocean" || tipo==="hidrografico"){//hidrografico
			icon=L.AwesomeMarkers.icon({icon: 'tint', prefix: 'fa', markerColor: 'blue'});
		}else if(tipo==="cape" || tipo==="bay" || tipo==="beach" || tipo==="costero"){//costero
			icon=L.AwesomeMarkers.icon({icon: 'anchor', prefix: 'fa', markerColor: 'orange'});
		}else if(tipo==="volcano" || tipo==="mountain_chain" || tipo==="mountain_range" || tipo==="relieve"){//relieve
			icon=L.AwesomeMarkers.icon({icon: 'tree', prefix: 'fa', markerColor: 'green'});
		}else{//defecto
			icon=L.AwesomeMarkers.icon({icon: 'map-pin', prefix: 'fa', markerColor: 'purple'});
		}
		
		return icon;
	}
	
	function mostrarPopUp(event){
		if($scope.event!==undefined){
			$scope.eventPrev=$scope.event;
		}
		$scope.event=event;
	}
	
	/**
	 * Vacia la lista de marcadores del mapa
	 */
	function eliminarMarcadores() {
		jQuery.each(markers, function() {
			 map.removeLayer(this);
		});
		markers=[];
		
	}
	
	/**
	 * Recibe peticion para crear marcadores de una serie de puntos.
	 */
	$scope.$on('createMarkersLocalizar', function(event, puntos) {
		featureGroupJugarLocalizar = L.featureGroup().addTo(map).on("click", mostrarPopUp);
		 for (var i = 0; i < puntos.length; i++) {
			 createMarkerLocalizar(puntos[i]);
		 }
		 map.fitBounds(featureGroupJugarLocalizar.getBounds(), {padding: [30, 30]});
			
	});
	
	/**
	 * Recibe peticion para crear un marcador seteando la vista.
	 */
	$scope.$on('createMarkersNombrar', function(event, nivelJuego, punto) {
		createMarkerNombrar(punto);
			
	});
	
	/**
	 * Recibe peticion para cambiar el icono del marcador a correcto o no
	 */
	$scope.$on('changeMarker', function(event, modoJuego, nivelJuego, correcto) {
		var icon;
		var iconDefault=L.AwesomeMarkers.icon({icon: 'check', prefix: 'fa', markerColor: 'cadetblue'});
		if(correcto){
			icon=L.AwesomeMarkers.icon({icon: 'check', prefix: 'fa', markerColor: 'green'});
		}else{
			icon=L.AwesomeMarkers.icon({icon: 'times', prefix: 'fa', markerColor: 'red'});
		}
		if(modoJuego==="localizar"){
			if(nivelJuego==="avanzado"){
				$scope.event.sourceTarget.setIcon(iconDefault);
			}else{
				$scope.event.sourceTarget.setIcon(icon);
				if(nivelJuego==="medio" && $scope.eventPrev!==undefined){//ponerle al anterior el icono de contestado si es nivel medio
					$scope.eventPrev.sourceTarget.setIcon(iconDefault);
				}
			}
		}else{
			if(nivelJuego==="avanzado"){
				$scope.markerPrev.setIcon(iconDefault);
			}else{
				$scope.markerPrev.setIcon(icon);
				if(nivelJuego==="medio" && $scope.markerPrevPrev!==undefined){//ponerle al anterior el icono de contestado si es nivel medio
					$scope.markerPrevPrev.setIcon(iconDefault);
				}
			}
		}
			
	});
	
	/**
	 * Crea un marcador con un popup en el mapa para funcionalidad de localizar punto
	 */
	function createMarkerLocalizar(place){
		popUpContent="<div class='col-12 font-18 no-padding'>";
		popUpContent=popUpContent+"<div class='col-12 font-16'>{{'label.confirmPointPlay'|translate}}</div>";
		popUpContent=popUpContent+"<div class='col-12 row no-margin'><button type='button' class='col-5 btn btn-success margin-top-15' ng-click='closePopUp(); $parent.comprobarPuntoLocalizar(place, event);'>{{'button.yes'|translate}}</button>",
		popUpContent=popUpContent+"<button type='button' class='col-5 ml-auto btn btn-danger margin-top-15' ng-click='closePopUp();'>{{'button.no'|translate}}</button></div>", 
		linkFunction=$compile(angular.element(popUpContent)),
		newScope=$scope.$new();
		newScope.place=place;
		var iconPlace=getIconByType(place.idTipoPunto.tipoPunto);
		var marker = L.marker([place.latitud, place.longitud], {icon:iconPlace}).addTo(featureGroupJugarLocalizar).bindPopup(linkFunction(newScope)[0]);
		markersLocalizar.push(marker);
		popUpContent="";
	}
	
	/**
	 * Crea un marcador centrado entre 4 limites para el modo de juego de NombrarPunto
	 */
	function createMarkerNombrar(place){
		var iconPlace=getIconByType(place.idTipoPunto.tipoPunto);
		var marker = L.marker([place.latitud, place.longitud], {icon:iconPlace}).addTo(map);
		var limite1 = L.marker([place.latitud, place.longitud+3]);
		var limite2 = L.marker([place.latitud, place.longitud-3]);
		var limite3 = L.marker([place.latitud+3, place.longitud]);
		var limite4 = L.marker([place.latitud-3, place.longitud]);
		markers.push(marker);
		markers.push(limite1);
		markers.push(limite2);
		markers.push(limite3);
		markers.push(limite4);
		
		var featureGroupNombrar = new L.FeatureGroup(markers);
		map.fitBounds(featureGroupNombrar.getBounds());
		if($scope.markerPrev!==undefined){
			$scope.markerPrevPrev=$scope.markerPrev;
		}
		$scope.markerPrev=marker;
		
	}

	/**
	 * Función para inicializar el mapa
	 */
	function initMap() {
		if($scope.jugar){//mapa mucho para jugar
			tileLayer='http://{s}.tiles.wmflabs.org/osm-no-labels/{z}/{x}/{y}.png';
		}else{
			tileLayer='http://{s}.tile.openstreetmap.org/{z}/{x}/{y}.png';
		}
			map = L.map('map',{scrollWheelZoom: false, dragging: !L.Browser.mobile, doubleClickZoom:false}).setView([40.4167, -3.70325], 6);
			L.tileLayer(tileLayer, {
			    attribution: 'Map data &copy; <a href="http://openstreetmap.org">OpenStreetMap</a> contributors, <a href="http://creativecommons.org/licenses/by-sa/2.0/">CC-BY-SA</a>, Imagery © <a href="http://cloudmade.com">CloudMade</a>',
			    maxZoom: 18
			}).addTo(map);
	}
	
	/**
	 * Recibe la peticion para inicializar el mapa
	 */
	$scope.$on('initMapa', function(event) {
		setTimeout(function(){
			initMap();
		}, 1000);
	});
	
	/**
	 * Controla el zoom del mapa con scroll + control
	 */
	$("#map").bind('mousewheel DOMMouseScroll', function (event) {
	    event.stopPropagation();
	     if (event.ctrlKey == true) {
	             event.preventDefault();
	         map.scrollWheelZoom.enable();
	           $('#map').removeClass('map-scroll');
	         setTimeout(function(){
	             map.scrollWheelZoom.disable();
	         }, 1000);
	     } else {
	         map.scrollWheelZoom.disable();
	         $('#map').addClass('map-scroll');
	     }

	 });

	/**
	 * Controla el scroll con dos dedos en dispositivos moviles
	 */
	/*$("#map").bind('touchstart', function (event) {
	    event.stopPropagation();
	     if (event.touches.length>1) {
	         event.preventDefault();
	         map.scrollWheelZoom.enable();
	           $('#map').removeClass('map-scroll map-scroll-mobile');
	         setTimeout(function(){
	             map.scrollWheelZoom.disable();
	         }, 1000);
	     } else {
	         map.scrollWheelZoom.disable();
	         $('#map').addClass('map-scroll map-scroll-mobile');
	     }

	 });*/

	/**
	 * Quitar el velo cuando se haga click
	 */
	$('#map').bind('click', function (event) {
	       $('#map').removeClass('map-scroll map-scroll-mobile');
	});
	
	/**
	 * Quitar el velo cuando se interactue con el resto de la pagina
	 */
	  $(window).bind('mousewheel DOMMouseScroll touchstart click', function (event) {
	       $('#map').removeClass('map-scroll map-scroll-mobile');
	  });
});

